# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v1.0.1](https://github.com/ljharb/data-view-buffer/compare/v1.0.0...v1.0.1) - 2024-02-06

### Commits

- [Refactor] use `es-errors`, so things that only need those do not need `get-intrinsic` [`675f588`](https://github.com/ljharb/data-view-buffer/commit/675f588236e489268de9f7a0adf33ef8295a3c71)
- [Deps] update `call-bind`, `get-intrinsic` [`e6eb209`](https://github.com/ljharb/data-view-buffer/commit/e6eb209578556ade150f0c3945cdeec9ffc582e2)

## v1.0.0 - 2024-02-02

### Commits

- Initial implementation, tests, readme, types [`2e1382b`](https://github.com/ljharb/data-view-buffer/commit/2e1382b26a98acc6f2ade4a061e1cd829e3043b8)
- Initial commit [`1eb7dc4`](https://github.com/ljharb/data-view-buffer/commit/1eb7dc4a0369d8320406bd7f9366c7887888790e)
- npm init [`d9e3d47`](https://github.com/ljharb/data-view-buffer/commit/d9e3d4707b54bf77de30565ea5c6c0fcdf4a0ecc)
- Only apps should have lockfiles [`116b60b`](https://github.com/ljharb/data-view-buffer/commit/116b60b9054de3331cd3c1599280466405c0d128)
